Catalogs and Sky Map
====================

Catalogs
--------
.. versionadded:: 0.2

.. automodule:: lsl.catalog
   :members:

Sky Map
-------
.. versionadded:: 0.2

.. automodule:: lsl.skymap
   :inherited-members:
   :members:
   
